@@ -5,8 +5,7 @@
 // SPDX-License-Identifier: GPL-3.0-or-later
 //
 
-#ifndef INCLUDED_UHD_VERSION_HPP
-#define INCLUDED_UHD_VERSION_HPP
+#pragma once
 
 /*!
  * The ABI version string that the client application builds against.
@@ -14,14 +13,14 @@
  * The format is oldest API compatible release - ABI compat number.
  * The compatibility number allows pre-release ABI to be versioned.
  */
-#define UHD_VERSION_ABI_STRING "3.15.0"
+#define UHD_VERSION_ABI_STRING "4.1.0"
 
 /*!
  * A macro to check UHD version at compile-time.
  * The value of this macro is MAJOR * 1000000 + API * 10000 + ABI * 100 + PATCH
  * (e.g., for UHD 3.10.0.1 this is 3100001).
  */
-#define UHD_VERSION 3150000
+#define UHD_VERSION 4010001
 
 #ifdef __cplusplus
 #include <uhd/config.hpp>
@@ -40,5 +39,3 @@ namespace uhd{
 
 } //namespace uhd
 #endif
-
-#endif /* INCLUDED_UHD_VERSION_HPP */
